{- |
Copyright: (c) 2022 Kowainik
SPDX-License-Identifier: BSD-3-Clause
Maintainer: Kowainik <xrom.xkov@gmail.com>

Cabal-only example with all integrations
-}

module CabalFull
    ( projectName
    ) where


projectName :: String
projectName = "cabal-full"
